@@ -1,17 +1,16 @@
 import string
 from typing import List, Union
-from multiprocessing import Pool
-from functools import partial
-import re
-from tqdm.contrib.concurrent import process_map  # or thread_map
-from itertools import product
 
 import spacy
 from sklearn.feature_extraction.text import TfidfVectorizer
 from sklearn.model_selection import train_test_split
+from tqdm.contrib.concurrent import process_map  # or thread_map
 
 from octis.dataset.dataset import Dataset
 
+"""
+Maps the language to its corresponding spacy model
+"""
 spacy_model_mapping = {'chinese': 'zh_core_web_sm', 'danish': 'nl_core_news_sm', 'dutch': 'nl_core_news_sm',
                        'english': 'en_core_web_sm', 'french': 'fr_core_news_sm', 'german': 'de_core_news_sm',
                        'greek': 'el_core_news_sm', 'italian': 'it_core_news_sm', 'japanese': 'ja_core_news_sm',
@@ -21,10 +20,53 @@ spacy_model_mapping = {'chinese': 'zh_core_web_sm', 'danish': 'nl_core_news_sm',
 
 
 class Preprocessing:
-    def __init__(self, lowercase=True, vocabulary=None, max_features=None, min_df=0.0, max_df=1.0,
-                 remove_punctuation=True, punctuation=string.punctuation, remove_numbers=True, lemmatize=True,
-                 stopword_list: Union[str, List[str]] = None, min_chars=1, min_words_docs=0, language='english',
-                 split=True, verbose=False, strip=True, num_processes=None):
+    def __init__(self, lowercase: bool = True, vocabulary: List[str] = None, max_features: int = None,
+                 min_df: float = 0.0, max_df: float = 1.0, remove_punctuation: bool = True,
+                 punctuation: str = string.punctuation, remove_numbers: bool = True, lemmatize: bool = True,
+                 stopword_list: Union[str, List[str]] = None, min_chars: int = 1, min_words_docs: int = 0,
+                 language: str = 'english', split: bool = True, verbose: bool = False, num_processes: int = None):
+        """
+        init Preprocessing
+
+        :param lowercase: if true, words in documents are reduced to lowercase (default: true)
+        :type lowercase: boolean
+        :param vocabulary: the vocabulary of the corpus to preprocess (default: None)
+        :type vocabulary: list
+        :param max_features: maximum number of words that the vocabulary must contain. The less frequent
+        words will be removed (default: None)
+        :type max_features: int
+        :param min_df: words below this minumum document frequency will be removed (default: 0.0)
+        :type min_df: float
+        :param max_df: words above this maximum document frequency will be removed (default: 1.0)
+        :type max_df: float
+        :param remove_punctuation: if true, punctuation will be removed (default: true)
+        :type remove_punctuation: bool
+        :param punctuation: string containing all the punctuation chars that need to be removed (default:
+        string.punctuation)
+        :type punctuation: str
+        :param remove_numbers: if true, numbers will be removed
+        :type remove_numbers: bool
+        :param lemmatize: if true, words will be lemmatized using a spacy model according to the language that has been
+        set (default: true)
+        :type lemmatize: bool
+        :param stopword_list: if a list of strings is passed, the strings will be removed from the texts. Otherwise,
+        if a str is passed, it represents the language of the stopwords that need to be removed. The stopwords are
+        spacy's stopwords (default: None)
+        :type stopword_list: str or list of str
+        :param min_chars: mininum number of characters that a token should have (default: 1)
+        :type min_chars: int
+        :param min_words_docs: minimun number of words that a document should contain (default: 0)
+        :type min_words_docs: int
+        :param language: language of the documents. It needs to be set for the lemmatizer (default: english)
+        :type language: str
+        :param split: if true, the corpus will be split in train (85%), testing (7.5%) and validation (7.5%) set (
+        default: true)
+        :type split: bool
+        :param verbose: if true, some steps of the preprocessing will be printed on screen (default: false)
+        :type verbose: bool
+        :param num_processes: number of processes to run the preprocessing
+        :type num_processes: int
+        """
         self.vocabulary = vocabulary
         self.lowercase = lowercase
         self.max_features = max_features
@@ -34,7 +76,6 @@ class Preprocessing:
         self.punctuation = punctuation
         self.lemmatize = lemmatize
         self.language = language
-        self.strip = strip
         self.num_processes = num_processes
         self.remove_numbers = remove_numbers
 
@@ -67,9 +108,20 @@ class Preprocessing:
         self.preprocessing_steps = []
 
     def preprocess_dataset(self, documents_path, labels_path=None):
+        """
+        preprocess the input dataset
+
+        :param documents_path: path to the documents file. Each row of the file represents a document
+        :type documents_path: str
+        :param labels_path: path to the documents file. Each row of the file represents a label. Its index corresponds
+        to the index of the documents file (default: None)
+        :type labels_path: str
+
+        :return octis.dataset.dataset.Dataset
+        """
         docs = [line.strip() for line in open(documents_path, 'r').readlines()]
         if self.num_processes is not None:
-            #with Pool(self.num_processes) as p:
+            # with Pool(self.num_processes) as p:
             #    docs = p.map(self.simple_preprocessing_steps, docs)
             docs = process_map(self.simple_preprocessing_steps, docs, max_workers=self.num_processes, chunksize=1)
         else:
@@ -83,7 +135,7 @@ class Preprocessing:
 
         vocabulary = self.filter_words(docs)
         print("created vocab")
-        #with Pool(self.num_processes) as p:
+        # with Pool(self.num_processes) as p:
         #    final_docs, final_labels = p.starmap(self._foo, product(docs, vocabulary, labels_path, repeat=2))
         print(len(vocabulary))
         final_docs, final_labels = [], []
@@ -164,6 +216,7 @@ class Preprocessing:
         vocabulary = vectorizer.get_feature_names()
         return vocabulary
 
+    '''
     def _foo(self, docs, vocabulary, labels_path):
         final_docs, final_labels = [], []
         if labels_path is not None:
@@ -180,28 +233,29 @@ class Preprocessing:
                 if len(new_doc) > self.min_doc_words:
                     final_docs.append(new_doc)
             return final_docs, []
+    '''
 
     def simple_preprocessing_steps(self, docs):
         tmp_docs = []
         for d in docs:
             new_d = d
-            if self.strip:
-                new_d = new_d.replace('\n', '')
-                new_d = new_d.replace('\t', '')
+            new_d = new_d.replace('\n', '')
+            new_d = new_d.replace('\t', '')
             if self.lowercase:
                 new_d = new_d.lower()
             if self.lemmatize:
                 if self.remove_stopwords_spacy:
                     new_d = ' '.join([token.lemma_ for token in self.spacy_model(new_d) if not token.is_stop])
                 elif self.stopwords:
-                    new_d = ' '.join([token.lemma_ for token in self.spacy_model(new_d) if token.lemma_ not in set(self.stopwords)])
+                    new_d = ' '.join(
+                        [token.lemma_ for token in self.spacy_model(new_d) if token.lemma_ not in set(self.stopwords)])
                 else:
                     new_d = ' '.join([token.lemma_ for token in self.spacy_model(new_d)])
 
             if self.remove_punctuation:
-                new_d = new_d.translate(str.maketrans(self.punctuation, ' '*len(self.punctuation)))
+                new_d = new_d.translate(str.maketrans(self.punctuation, ' ' * len(self.punctuation)))
             if self.remove_numbers:
-                new_d = new_d.translate(str.maketrans("0123456789", ' '*len("0123456789")))
+                new_d = new_d.translate(str.maketrans("0123456789", ' ' * len("0123456789")))
             new_d = " ".join(new_d.split())
             tmp_docs.append(new_d)
         return tmp_docs
